
#ifndef _C1_kl5_
#define _C1_kl5_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F5_55(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit5(void);

#ifdef __cplusplus
}
#endif

#endif
